@@ -47,9 +47,15 @@ expects is reported immediately via an exception.
 
 =item * Light memory footprint - no Moose/Moo/etc.
 
-=item * Only one non-core, non-pure-Perl dependency (L<Crypt::OpenSSL::RSA>),
-and there’s a fallback to the system C<openssl> binary if that module isn’t
-available. Net::ACME should run almost anywhere!
+=item * No careless overwriting of globals like C<$@>, C<$!> and C<$?>.
+(Hopefully your code isn’t susceptible to this anyway, but it’s just a good
+precaution.)
+B<NOTE>: Perl 5.10 and earlier have a bug that basically requires overwriting
+global C<$@>; see C<Net::ACME::EvalBug> for an example.
+
+=item * All dependencies are either core or pure Perl. For RSA crypto we use
+L<Crypt::OpenSSL::RSA> if it’s available, or the system’s C<openssl> binary.
+Net::ACME will run almost anywhere!
 
 =back
 
@@ -190,6 +196,8 @@ I am aware of the following additional CPAN modules that implement this protocol
 
 =item * L<WWW::LetsEncrypt>
 
+=item * L<Mojo::ACME>
+
 =back
 
 =head1 REPOSITORY (FEEDBACK/BUGS)
@@ -200,6 +208,10 @@ L<https://github.com/FGasper/p5-Net-ACME>
 
 Felipe Gasper (FELIPE)
 
+=head1 LICENSE
+
+This module is licensed under the same terms as Perl.
+
 =cut
 
 use strict;
@@ -215,6 +227,7 @@ use Net::ACME::Certificate                 ();
 use Net::ACME::Certificate::Pending        ();
 use Net::ACME::Constants                   ();
 use Net::ACME::Challenge::Pending::http_01 ();
+use Net::ACME::EvalBug ();
 use Net::ACME::HTTP                        ();
 use Net::ACME::Registration                ();
 use Net::ACME::Utils                       ();
@@ -376,8 +389,10 @@ sub start_domain_authz {
 sub delete_authz {
     my ( $self, $authz ) = @_;
 
+    local $@ if !Net::ACME::EvalBug::bug_exists();
+
     #sanity
-    if ( !UNIVERSAL::isa( $authz, 'Net::ACME::Authorization::Pending' ) ) {
+    if ( !eval { $authz->isa('Net::ACME::Authorization::Pending') } ) {
         die "Must be a pending authz object, not “$authz”!";
     }
 
